@@ -99,7 +99,7 @@ class DataCulpaValidator:
     # FIXME: http, message queues, etc.
 
     def __init__(self, 
-                 watchpoint_name, 
+                 watchpoint_name=None, 
                  watchpoint_environment="default",
                  watchpoint_stage="default",
                  watchpoint_version="default",
@@ -110,7 +110,8 @@ class DataCulpaValidator:
                  api_secret=None,
                  queue_window=20,
                  timeshift=None,
-                 use_fastcols=False):
+                 use_fastcols=False,
+                 watchpoint_id=None):
 
         if api_access_id is None or api_secret is None:
             sys.stderr.write("Warning: api_access_id is required with Validator 1.1 and later.\n")
@@ -120,6 +121,7 @@ class DataCulpaValidator:
         self.watchpoint_environment = watchpoint_environment
         self.watchpoint_stage       = watchpoint_stage
         self.watchpoint_version     = watchpoint_version
+        self.explicit_watchpoint_id = watchpoint_id
 
         self._fastcols              = use_fastcols
         self.protocol = protocol
@@ -132,6 +134,7 @@ class DataCulpaValidator:
         self.port = dc_port
         self.api_access_id = api_access_id
         self.api_secret = api_secret
+        self.local_only = False
         self.queue_window = queue_window
         self._queue_buffer = []
         self._queue_ready = False
@@ -511,15 +514,21 @@ class DataCulpaValidator:
         return
 
     def _open_queue(self):
-        j = { 
-                'pipeline' : self.watchpoint_name,
-                'context'  : self.watchpoint_environment,
-                'stage'    : self.watchpoint_stage,
-                'version'  : self.watchpoint_version,
-                'timeshift': self._calc_timeshift_seconds(),
-                'fastcols':  self._fastcols
-        }
-
+        if self.explicit_watchpoint_id:
+            j = { 'pipeline_id': self.explicit_watchpoint_id,
+                  'fastcols':    self._fastcols
+            }
+        else:
+            j = { 
+                    'pipeline' : self.watchpoint_name,
+                    'context'  : self.watchpoint_environment,
+                    'stage'    : self.watchpoint_stage,
+                    'version'  : self.watchpoint_version,
+                    'timeshift': self._calc_timeshift_seconds(),
+                    'fastcols':  self._fastcols
+            }
+        # endif
+        
         self._login_if_needed()
         rs_str = json.dumps(j, cls=json.JSONEncoder, default=str)
         post_url = self._get_base_url("queue/open")
@@ -607,6 +616,8 @@ class DataCulpaValidator:
         return jr
 
     def login(self):
+        if self.local_only:
+            return
         assert self.api_access_id is not None, "need to pass api_access_id and api_secret when creating DataCulpaValidator object"
         assert self.api_secret is not None,    "need to pass api_access_id and api_secret when creating DataCulpaValidator object"
 
